import serial
import time
#from importlib import resources
#import io


def openSer(COM, Baud, timeout):
    global ser
    ser = serial.Serial(COM, Baud, timeout=timeout)
    return ser

def startMotors(ser):
    ser.write(bytes.fromhex("6E"))
    ser.write(bytes.fromhex("65"))


def reset(ser):
    ser.write(bytes.fromhex("6c"))
    time.sleep(0.1)
    ser.write(bytes.fromhex("76"))


def error(ser):
    dataList = readData("1A", ser)
    if (dataList[0] == "xff"):
        print("Motor vertical has an error!")
        print("To reset both Motors call function: reset()")
        disable(ser)
    elif (dataList[1] == "xff"):
        print("Motor horizontal has an error!")
        print("To reset both Motors call function: reset()")
        disable(ser)

def disable(ser):
    ser.write(bytes.fromhex("6E"))


def closeSer(ser):
    ser.close()

def readData(hexCode, ser):
    ser.write(bytes.fromhex(hexCode))
    time.sleep(0.1)
    hex_response = ser.readline()
    time.sleep(0.1)
    return hex_response








import igusD1
import time
#  Motor horizontal (hor)

def isRefHorizontal(ser):
    dataList = []
    data = str(igusD1.initialisierung.readData("1A", ser))
    dataList = data.split('\\')

    igusD1.initialisierung.error(ser)
    if (dataList[3] != "xff"):
        ref_horizontal(ser)


def horIsActive(ser):
    dataList = []
    isActive = True
    while (isActive == True):
        # Wait unitl its not active anymore
        dataList.clear()  # clear list
        data = str(igusD1.initialisierung.readData("1A", ser))  # new values to variable
        dataList = data.split('\\')
        if dataList[7] == "xff":
            isActiv = True
        elif dataList[7] != "xff":
            isActive = False


def ref_horizontal(ser):
    print("Is Refernzing hor now")
    ser.write(bytes.fromhex("75"))
    ser.write(bytes.fromhex("76"))
    time.sleep(0.01)
    ser.write(bytes.fromhex("67"))
    horIsActive(ser)


def pos1_horizontal(ser):
    isRefHorizontal(ser)
    ser.write(bytes.fromhex("6A"))
    ser.write(bytes.fromhex("74"))
    time.sleep(0.01)
    ser.write(bytes.fromhex("67"))
    time.sleep(0.1)
    print("MotorHor is going to pos1")
    ser.write(bytes.fromhex("71"))
    horIsActive(ser)
    print("MotorHor Pos1: " + str(igusD1.initialisierung.readData("1A", ser)))


def pos2_horizontal(ser):
    isRefHorizontal(ser)
    ser.write(bytes.fromhex("73"))
    ser.write(bytes.fromhex("6B"))
    time.sleep(0.01)
    ser.write(bytes.fromhex("67"))
    time.sleep(0.1)
    print("MotorHor is going to pos2")
    ser.write(bytes.fromhex("71"))
    horIsActive(ser)
    print("MotorHor Pos2: " + str(igusD1.initialisierung.readData("1A", ser)))


def pos3_horizontal(ser):
    isRefHorizontal(ser)
    ser.write(bytes.fromhex("6A"))
    ser.write(bytes.fromhex("6B"))
    time.sleep(0.01)
    ser.write(bytes.fromhex("67"))
    time.sleep(0.1)
    print("MotorHor is going to pos3")
    ser.write(bytes.fromhex("71"))
    horIsActive(ser)
    print("MotorHor Pos3: " + str(igusD1.initialisierung.readData("1A", ser)))


import igusD1
import time

def isRefVertical(ser):
    dataList = []
    data = str(igusD1.initialisierung.readData("1A", ser))
    dataList = data.split('\\')
    igusD1.initialisierung.error(ser)
    if (dataList[3] != "xff"):
        ref_vertikal(ser)


def vertIsActive(ser):
    dataList = []
    isActive = True
    while (isActive == True):
        # Wait unitl its not active anymore
        dataList.clear()  # clear list
        data = str(igusD1.initialisierung.readData("1A", ser))  # new values to variable
        dataList = data.split('\\')
        if dataList[4] == "xff":
            isActiv = True
        elif dataList[7] != "xff":
            isActive = False



def ref_vertikal(ser):
    print("Is Referencing vert now")
    ser.write(bytes.fromhex("72"))
    ser.write(bytes.fromhex("73"))
    time.sleep(0.01)
    ser.write(bytes.fromhex("66"))
    time.sleep(0.01)
    vertIsActive(ser)



def pos1_vertikal(ser):
    isRefVertical(ser)
    ser.write(bytes.fromhex("68"))
    ser.write(bytes.fromhex("73"))
    time.sleep(0.01)
    ser.write(bytes.fromhex("66"))
    time.sleep(0.1)
    print("MotorVert is going to pos1")
    ser.write(bytes.fromhex("70"))
    vertIsActive(ser)
    data = str(igusD1.initialisierung.readData("1A", ser))
    print("MotorVert Pos1: " + data)


def pos2_vertikal(ser):
    isRefVertical(ser)
    ser.write(bytes.fromhex("72"))
    ser.write(bytes.fromhex("69"))
    time.sleep(0.01)
    ser.write(bytes.fromhex("66"))
    time.sleep(0.1)
    print("MotorVert is going to pos2")
    ser.write(bytes.fromhex("70"))
    vertIsActive(ser)
    print("MotorVert Pos2: " + str(igusD1.initialisierung.readData("1A", ser)))


def pos3_vertikal(ser):
    isRefVertical(ser)
    ser.write(bytes.fromhex("68"))
    ser.write(bytes.fromhex("69"))
    time.sleep(0.01)
    ser.write(bytes.fromhex("66"))
    time.sleep(0.1)
    print("MotorVert is going to pos3")
    ser.write(bytes.fromhex("70"))
    vertIsActive(ser)
    print("MotorVert Pos3: " + str(igusD1.initialisierung.readData("1A", ser)))


from setuptools import find_packages
from setuptools import setup


VERSION = '0.0.2'
DESCRIPTION = 'Package for Ingus D1 '
LONG_DESCRIPTION = 'file: README.md'

# Setting up
setup(
        # the name must match the folder name 'verysimplemodule'
        name="IgusD1",
        version=VERSION,
        author="Niklas Kuehnl",
        author_email="<niklas.kuehnl@beurer.de>",
        description=DESCRIPTION,
        long_description=LONG_DESCRIPTION,
        packages=find_packages(),
        install_requires=[],  # add any additional packages that
        # needs to be installed along with your package. Eg: 'caer'

        keywords=['python', 'first package'],
        classifiers=[
                "Development Status :: 3 - Alpha",
                "Intended Audience :: Education",
                "Programming Language :: Python :: 2",
                "Programming Language :: Python :: 3",
                "Operating System :: MacOS :: MacOS X",
                "Operating System :: Microsoft :: Windows",
        ]
)
